@@ -7,14 +7,17 @@ def handle_response(func):
     @wraps(func)
     def inner_function(*args, **kwargs):
         result = func(*args, **kwargs)
+
+        response = result
+        code = 200
+        use_default_response_message_key = True
+
         if isinstance(result, tuple):
             response = result[0]
             code = result[1]
-        else:
-            response = result
-            code = 200
+            use_default_response_message_key = result[2]
 
-        if code not in [200, 201, 204]:
+        if code not in [200, 201, 204] and use_default_response_message_key:
             response = dict(message=response)
 
         return Response(
