@@ -61,20 +61,34 @@ class MicroFetcher(object):
         output = dict()
         for index, item in enumerate(self.base_data):
             for search_column in self.search_configs.get("search_priority"):
-                value = item.get(search_column)
+                sanitize = None
+                if isinstance(search_column, dict):
+                    search_column_name = search_column.get('key')
+                    operator = search_column.get('operator') or "IN"
+                    sanitize = search_column.get('sanitize')
+                else:
+                    search_column_name = search_column
+                    operator = 'IN'
+
+                value = item.get(search_column_name)
+                if sanitize and isinstance(sanitize, list):
+                    for _san in sanitize:
+                        value = _san(value)
+
                 if value:
-                    if not output.get(search_column):
-                        output[search_column] = dict(
-                            search_key=search_column,
+                    if not output.get(search_column_name):
+                        output[search_column_name] = dict(
+                            search_key=search_column_name,
+                            operator=operator,
                             inputs=dict()
                         )
-                    if not output[search_column]['inputs'].get(value):
-                        output[search_column]['inputs'][value] = dict(
+                    if not output[search_column_name]['inputs'].get(value):
+                        output[search_column_name]['inputs'][value] = dict(
                             indexes=[index],
                             search_value=value
                         )
                     else:
-                        output[search_column]['inputs'][value]["indexes"].append(index)
+                        output[search_column_name]['inputs'][value]["indexes"].append(index)
                     break
 
         output = list(output.values())
@@ -208,9 +222,11 @@ class MicroFetcher(object):
                 for _input in item.get('inputs'):
                     for _index in _input.get('indexes'):
                         self.base_data[_index][self.output_key] = _input.get('matched_id')
-                        append_extra = self.search_configs.get('append_extra') if isinstance(self.search_configs, dict) else []
+                        append_extra = self.search_configs.get('append_extra') if isinstance(self.search_configs,
+                                                                                             dict) else []
                         for _ap_col in append_extra:
-                            self.base_data[_index][_ap_col] = _input.get(_ap_col)
+                            self.base_data[_index][_ap_col] = _input.get(_ap_col) if _input.get('matched_id') else \
+                                self.base_data[_index].get(_ap_col)
 
             validation_result = []
             for _val in result.get("validation"):
